@@ -10,6 +10,7 @@ use strict;
 sub new {
   my ($class, %params) = @_;
   my $self = {};
+  $self->{htmlstart} = 1;
   $self->{full_page} = 1; 
   $self->{title} = 0;
   $self->{bg_image} = '';
@@ -64,7 +65,7 @@ sub info_general {
   my %param = @_;
   error_msg("invalid parameter") if (defined $_[0] && exists $param{'links'} && ref $param{'links'} ne 'ARRAY');   
   $self->links(@{$param{'links'}}) if exists $param{'links'};
-  my $html;
+  my $html = "";
   $self->{title} = 'perlinfo(INFO_GENERAL)' unless $self->{title};
   $html .= $self->print_htmlhead() if $self->{full_page};
   $html .= print_general('top');
@@ -78,7 +79,14 @@ my $self = shift;
 $self->{'title'} = 'perlinfo(INFO_LOADED)' unless $self->{'title'};
 my $html;
 $html .= $self->print_htmlhead() if $self->{'full_page'};
+$html .= print_general();
+delete $INC{'HTML/Perlinfo.pm'};
+$html .= print_thesemodules('loaded',[values %INC]);
+$html .= print_variables();
+$html .= '</div></body></html>' if $self->{'full_page'};
+defined wantarray ? return $html : print $html;
 
+=pod
 eval qq{
 
 END {
@@ -90,7 +98,7 @@ END {
  }
 
 }; die $@ if $@;
-
+=cut;
 }
 
 sub info_modules {
@@ -125,7 +133,7 @@ sub info_apache {
   my $html;
   $self->{title} = 'perlinfo(INFO_APACHE)' unless $self->{title};
   $html .= $self->print_htmlhead() if $self->{full_page};
-  $html .= print_httpd();
+  $html .= print_httpd() if print_httpd();
   $html .= "</div></body></html>" if $self->{full_page};
   defined wantarray ? return $html : print $html;
 }
@@ -156,6 +164,16 @@ sub info_license {
 }
 
 
+sub print_htmlstart {
+  my $html = <<"END_OF_HTML";
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
+"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
+<head>
+END_OF_HTML
+}
+
 sub print_htmlhead {
 	
   my $self = shift;
@@ -181,46 +199,44 @@ sub print_htmlhead {
   my $rightcol_bgcolor = $self->{rightcol_bgcolor};
   my $rightcol_ftcolor = $self->{rightcol_ftcolor};
 
-  my $html = <<"END_OF_HTML";
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
-<head>
+
+  my $html = $self->{htmlstart} ? $self->print_htmlstart() : "";
+
+  $html .= <<"END_OF_HTML";
 <style type="text/css"><!--
-body {
+#perlinfo div {
 background-color: $bg_color; 
 background-image: url($bg_image);
 background-position: $bg_position;
 background-repeat: $bg_repeat;
 background-attachment: $bg_attribute;  
-color: $ft_color;}
-body, td, th, h1, h2 {font-family: $ft_family;}
-pre {margin: 0px; font-family: monospace;}
-a:link {color: $lk_color; text-decoration: $lk_decoration; background-color: $lk_bgcolor;}
-a:hover {text-decoration: $lk_hvdecoration;}
-table {border-collapse: collapse;}
-.center {text-align: center;}
-.center table { margin-left: auto; margin-right: auto; text-align: left;}
-.center th { text-align: center !important; }
-td, th { border: 1px solid #000000; font-size: 75%; vertical-align: baseline;}
-.modules table {border: 0;}
-.modules td { border:0; font-size: 100%; vertical-align: baseline;}
-.modules th { border:0; font-size: 100%; vertical-align: baseline;}
-h1 {font-size: 150%;}
-h2 {font-size: 125%;}
-.p {text-align: left;}
-.e {background-color: $leftcol_bgcolor; font-weight: bold; color: $leftcol_ftcolor;}
-.h {background-color: $header_bgcolor; font-weight: bold; color: $header_ftcolor;}
-.v {background-color: $rightcol_bgcolor; color: $rightcol_ftcolor;}
-i {color: #666666; background-color: #cccccc;}
-img {float: right; border: 0px;}
-hr {width: 600px; background-color: #cccccc; border: 0px; height: 1px; color: #000000;}
+color: $ft_color;
+}
+#perlinfo td, th, h1, h2 {font-family: $ft_family;}
+#perlinfo pre {margin: 0px; font-family: monospace;}
+#perlinfo a:link {color: $lk_color; text-decoration: $lk_decoration; background-color: $lk_bgcolor;}
+#perlinfo a:hover {text-decoration: $lk_hvdecoration;}
+#perlinfo table {border-collapse: collapse;}
+#perlinfo > h1,#perlinfo > h2 {text-align: center;}
+#perlinfo div.center table { margin-left: auto; margin-right: auto; text-align: left;}
+#perlinfo div.center th { text-align: center !important; }
+#perlinfo td, th { border: 1px solid #000000; font-size: 75%; vertical-align: baseline;}
+#perlinfo .modules table {border: 0;}
+#perlinfo .modules td { border:0; font-size: 100%; vertical-align: baseline;}
+#perlinfo .modules th { border:0; font-size: 100%; vertical-align: baseline;}
+#perlinfo h1 {font-size: 150%;}
+#perlinfo h2 {font-size: 125%;}
+#perlinfo .p {text-align: left;}
+#perlinfo .e {background-color: $leftcol_bgcolor; font-weight: bold; color: $leftcol_ftcolor;}
+#perlinfo .h {background-color: $header_bgcolor; font-weight: bold; color: $header_ftcolor;}
+#perlinfo .v {background-color: $rightcol_bgcolor; color: $rightcol_ftcolor;}
+#perlinfo i {color: #666666; background-color: #cccccc;}
+#perlinfo img {float: right; border: 0px;}
+#perlinfo hr {width: 600px; background-color: #cccccc; border: 0px; height: 1px; color: #000000;}
 //--></style>
-<title>$title</title>
-</head>
-<body><div class="center">
 END_OF_HTML
+$html .= "<title>$title</title></head><body>" if $self->{htmlstart};
+$html .= '<div id="perlinfo" class="center">';
 
 defined wantarray ? return $html : print $html;
 }
