@@ -10,7 +10,7 @@ use base qw(HTML::Perlinfo::Base);
 use CGI qw(escapeHTML);
 use HTML::Perlinfo::Common;
 
-our $VERSION = '1.17';
+our $VERSION = '1.19';
 
 
 sub new {
@@ -46,7 +46,7 @@ sub get_files_in {
 
     my ($file_path) = @_;
  
-    return 0 unless $file_path =~ m/\.pm$/; 
+    return 0 unless $file_path && $file_path =~ m/\.pm$/; 
     my $mod_info = module_info($file_path, undef);
     return $mod_info;
 
